=== modified file 'bzrlib/fetch.py'
--- bzrlib/fetch.py	2005-10-08 00:32:39 +0000
+++ bzrlib/fetch.py	2005-10-09 22:43:56 +0000
@@ -104,6 +104,12 @@
         else:
             self.pb = pb
         try:
+            self._fetch_revisions(last_revision)
+        finally:
+            self.pb.clear()
+
+    def _fetch_revisions(self, last_revision):
+        try:
             self.last_revision = self._find_last_revision(last_revision)
         except NoSuchRevision, e:
             mutter('failed getting last revision: %s', e)
@@ -116,7 +122,6 @@
         self._copy_revisions(revs_to_fetch)
         self.new_ancestry = revs_to_fetch
 
-
     def _find_last_revision(self, last_revision):
         """Find the limiting source revision.
 

=== modified file 'bzrlib/merge.py'
--- bzrlib/merge.py	2005-10-08 00:02:33 +0000
+++ bzrlib/merge.py	2005-10-08 05:21:30 +0000
@@ -29,7 +29,7 @@
 from bzrlib.errors import BzrCommandError, UnrelatedBranches, NoCommonAncestor
 from bzrlib.errors import NoCommits
 from bzrlib.delta import compare_trees
-from bzrlib.trace import mutter, warning
+from bzrlib.trace import mutter, warning, note
 from bzrlib.fetch import greedy_fetch, fetch
 from bzrlib.revision import is_ancestor
 from bzrlib.osutils import rename
@@ -39,6 +39,8 @@
 # TODO: build_working_dir can be built on something simpler than merge()
 
 # FIXME: merge() parameters seem oriented towards the command line
+# NOTABUG: merge is a helper for commandline functions.  merge_inner is the
+#          the core functionality.
 
 # comments from abentley on irc: merge happens in two stages, each
 # of which generates a changeset object
@@ -190,7 +192,7 @@
 
     def finalize(self):
         if not self.ignore_zero:
-            print "%d conflicts encountered.\n" % self.conflicts
+            note("%d conflicts encountered.\n" % self.conflicts)
             
 def get_tree(treespec, temp_root, label, local_branch=None):
     location, revno = treespec

=== modified file 'bzrlib/selftest/testbranch.py'
--- bzrlib/selftest/testbranch.py	2005-10-07 04:10:46 +0000
+++ bzrlib/selftest/testbranch.py	2005-10-09 22:43:56 +0000
@@ -19,11 +19,11 @@
 from bzrlib.clone import copy_branch
 from bzrlib.commit import commit
 import bzrlib.errors as errors
-from bzrlib.errors import NoSuchRevision, UnlistableBranch
+from bzrlib.errors import NoSuchRevision, UnlistableBranch, NotBranchError
 from bzrlib.selftest import TestCaseInTempDir
 from bzrlib.trace import mutter
 import bzrlib.transactions as transactions
-
+from bzrlib.selftest.HTTPTestUtil import TestCaseWithWebserver
 
 class TestBranch(TestCaseInTempDir):
 
@@ -140,8 +140,19 @@
                            'wibble@fofof--20050401--1928390812')
         # list should be cleared when we do a commit
         self.assertEquals(b.pending_merges(), [])
- 
-
+
+
+class TestRemote(TestCaseWithWebserver):
+
+    def test_open_containing(self):
+        self.assertRaises(NotBranchError, Branch.open_containing,
+                          self.get_remote_url(''))
+        self.assertRaises(NotBranchError, Branch.open_containing,
+                          self.get_remote_url('g/p/q'))
+        b = Branch.initialize('.')
+        Branch.open_containing(self.get_remote_url(''))
+        Branch.open_containing(self.get_remote_url('g/p/q'))
+        
 # TODO: rewrite this as a regular unittest, without relying on the displayed output        
 #         >>> from bzrlib.commit import commit
 #         >>> bzrlib.trace.silent = True

=== modified file 'bzrlib/transport/http.py'
--- bzrlib/transport/http.py	2005-10-04 04:37:29 +0000
+++ bzrlib/transport/http.py	2005-10-08 06:41:21 +0000
@@ -89,7 +89,8 @@
                     # In most filesystems, a request for the parent
                     # of root, just returns root.
                     continue
-                basepath.pop()
+                if len(basepath) > 0:
+                    basepath.pop()
             elif p == '.':
                 continue # No-op
             else:

=== modified file 'setup.py' (properties changed: -x to +x)
